/**
 * Copyright (C) 2010-2011 enStratusNetworks LLC
 *
 * ====================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ====================================================================
 */

package org.dasein.cloud.jclouds.rackspace.network;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Locale;

import org.dasein.cloud.CloudException;
import org.dasein.cloud.InternalException;
import org.dasein.cloud.OperationNotSupportedException;
import org.dasein.cloud.jclouds.rackspace.RackspaceCloud;
import org.dasein.cloud.network.AddressType;
import org.dasein.cloud.network.IpAddress;
import org.dasein.cloud.network.IpAddressSupport;
import org.dasein.cloud.network.IpForwardingRule;
import org.dasein.cloud.network.Protocol;

public class RackspaceAddress implements IpAddressSupport {
    @SuppressWarnings("unused")
    private RackspaceCloud provider = null;
    
    RackspaceAddress(RackspaceCloud provider) { this.provider = provider; }

    @Override
	public void assign(String addressId, String serverId) throws InternalException, CloudException {
		throw new OperationNotSupportedException();
	}

    @Override
    public String forward(String addressId, int publicPort, Protocol protocol, int privatePort, String onServerId) throws InternalException, CloudException {
        throw new OperationNotSupportedException("Forwarding not supported");
    }
    
    @Override
	public IpAddress getIpAddress(String addressId) throws InternalException, CloudException {
	    return null;
	}

    @Override
	public String getProviderTermForIpAddress(Locale locale) {
		return "address";
	}

    @Override
    public Iterable<IpAddress> listPrivateIpPool(boolean unassignedOnly) throws InternalException, CloudException {
        return Collections.emptyList();
    }
    
    @Override
    public Iterable<IpAddress> listPublicIpPool(boolean unassignedOnly) throws InternalException, CloudException {
        return Collections.emptyList();
    }
    
    @Override
    public Collection<IpForwardingRule> listRules(String addressId) throws InternalException, CloudException {
        return new ArrayList<IpForwardingRule>();
    }

    @Override
    public boolean isAssigned(AddressType type) {
        return false;
    }

    @Override
    public boolean isForwarding() {
        return false;
    }

    @Override
    public boolean isRequestable(AddressType type) {
        return false;
    }
    
    @Override
    public boolean isSubscribed() throws CloudException, InternalException {
        return false;
    }
    
    @Override
    public void releaseFromPool(String addressId) throws InternalException, CloudException {
        throw new OperationNotSupportedException();
    }

    @Override
    public void releaseFromServer(String addressId) throws InternalException, CloudException {
        throw new OperationNotSupportedException();
    }

    @Override
    public String request(AddressType type) throws InternalException, CloudException {
        throw new OperationNotSupportedException();
    }
    
    @Override
    public void stopForward(String ruleId) throws InternalException, CloudException {
        throw new OperationNotSupportedException();
    }
}
